utility functions
*****************

Some utility functions

prepare_data
============
.. automodule:: ai4water.utils.utils
   :members: prepare_data

get_attributes
==============
.. automodule:: ai4water.backend
   :members: get_attributes

murphy_diagram
==============
.. automodule:: ai4water.utils.visualizations
   :members: murphy_diagram

fdc_plot
==============
.. automodule:: ai4water.utils.visualizations
   :members: fdc_plot

edf_plot
========
.. automodule:: ai4water.utils.visualizations
   :members: edf_plot

jsonize
=======
.. automodule:: ai4water.utils.utils
   :members: jsonize


TrainTestSplit
===============
.. automodule:: ai4water.utils.utils
   :members: TrainTestSplit